# ActivitiesSummary

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDate**](LastModifiedDate.md) |  | [optional] 
**educations** | [**Educations**](Educations.md) |  | [optional] 
**employments** | [**Employments**](Employments.md) |  | [optional] 
**fundings** | [**Fundings**](Fundings.md) |  | [optional] 
**peer_reviews** | [**PeerReviews**](PeerReviews.md) |  | [optional] 
**works** | [**Works**](Works.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


